# frozen_string_literal: true

SpiritHub::Engine.routes.draw do # rubocop:disable Metrics/BlockLength
  scope path: '/spirit_hub', as: 'spirit_hub' do # rubocop:disable Metrics/BlockLength
    resources :favorites, only: %i[index] do
      collection do
        get 'sort'
        put 'update_shown_columns'
        put 'update_view_type'
      end

      member do
        delete 'remove'
      end
    end

    resources :to_categorizes, only: %i[index] do
      collection do
        get 'sort'
        put 'update_shown_columns'
        put 'update_view_type'
        get 'categorize_form'
        post 'add_to_directory'
      end
    end

    resources :todos, only: %i[index] do
      collection do
        get 'sort'
        put 'update_shown_columns'
        put 'update_view_type'
      end
    end

    resources :tagsets, only: %i[] do
      collection do
        get 'search_directories'
        get 'add_doc_form'
        post 'add_doc'
        post 'bulk_delete'
      end

      member do
        get 'logs'
        get 'doc/:doc_id', to: 'tagsets#doc', as: 'doc'
        get 'docs'
        get 'share_form'
        post 'share'
        put 'add_favorite'
        put 'remove_favorite'
        delete 'delete_item'
      end
    end

    resources :directories, only: %i[] do
      member do
        get 'index'
        get 'sort'
        put 'update_shown_columns'
        put 'update_view_type'
        delete 'remove/:tagset_id', action: :remove, as: :remove
        post 'bulk_delete'
        get 'add_doc_to_completeness_form/:completeness_id', action: :add_doc_to_completeness_form, as: :add_doc_to_completeness_form
        post 'add_doc_to_completeness/:completeness_id', action: :add_doc_to_completeness, as: :add_doc_to_completeness
        get 'add_doc_to_tagset_doc_form/:tagset_id', action: :add_doc_to_tagset_doc_form, as: :add_doc_to_tagset_doc_form
        post 'add_doc_to_tagset_doc/:tagset_id', action: :add_doc_to_tagset_doc, as: :add_doc_to_tagset_doc
        delete 'remove_doc_from_tagset_doc/:tagset_id/:doc_id', action: :remove_doc_from_tagset_doc, as: :remove_doc_from_tagset_doc
      end
    end

    get 'search', to: 'search#index', as: :search_index
    get 'search/sort', to: 'search#sort'

    scope :shared do
      get '/', to: 'shared#index', as: 'shared_index'
      get 'sort', to: 'shared#sort', as: 'shared_sort'
      put 'update_shown_columns', to: 'shared#update_shown_columns', as: 'shared_update_shown_columns'
      put 'update_view_type', to: 'shared#update_view_type', as: 'shared_update_view_type'
    end
    resources :team_activity, only: %i[index] do
    end
  end
end
